@@ -115,6 +115,14 @@ class GameSparksClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_gamesparks/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_gamesparks/client/#close)
+        """
+
     def create_game(
         self,
         *,
@@ -290,7 +298,7 @@ class GameSparksClient(BaseClient):
         """
 
     def import_game_configuration(
-        self, *, GameName: str, ImportSource: "ImportGameConfigurationSourceTypeDef"
+        self, *, GameName: str, ImportSource: ImportGameConfigurationSourceTypeDef
     ) -> ImportGameConfigurationResultTypeDef:
         """
         Imports a game configuration.
@@ -376,7 +384,7 @@ class GameSparksClient(BaseClient):
         """
 
     def start_generated_code_job(
-        self, *, GameName: str, Generator: "GeneratorTypeDef", SnapshotId: str
+        self, *, GameName: str, Generator: GeneratorTypeDef, SnapshotId: str
     ) -> StartGeneratedCodeJobResultTypeDef:
         """
         Starts an asynchronous process that generates client code for system-defined and
@@ -421,7 +429,7 @@ class GameSparksClient(BaseClient):
         """
 
     def update_game_configuration(
-        self, *, GameName: str, Modifications: Sequence["SectionModificationTypeDef"]
+        self, *, GameName: str, Modifications: Sequence[SectionModificationTypeDef]
     ) -> UpdateGameConfigurationResultTypeDef:
         """
         Updates one or more sections of the game configuration.
