@@ -33,8 +33,7 @@ Usage::
 """
 from typing import Generic, Iterator, TypeVar
 
-from botocore.paginate import PageIterator
-from botocore.paginate import Paginator as Boto3Paginator
+from botocore.paginate import PageIterator, Paginator
 
 from .type_defs import (
     ListExtensionsResultTypeDef,
@@ -68,14 +67,14 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
         """
 
 
-class ListExtensionVersionsPaginator(Boto3Paginator):
+class ListExtensionVersionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListExtensionVersions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_gamesparks/paginators/#listextensionversionspaginator)
     """
 
     def paginate(
-        self, *, Name: str, Namespace: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, Name: str, Namespace: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListExtensionVersionsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListExtensionVersions.paginate)
@@ -83,14 +82,14 @@ class ListExtensionVersionsPaginator(Boto3Paginator):
         """
 
 
-class ListExtensionsPaginator(Boto3Paginator):
+class ListExtensionsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListExtensions)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_gamesparks/paginators/#listextensionspaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListExtensionsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListExtensions.paginate)
@@ -98,14 +97,14 @@ class ListExtensionsPaginator(Boto3Paginator):
         """
 
 
-class ListGamesPaginator(Boto3Paginator):
+class ListGamesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListGames)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_gamesparks/paginators/#listgamespaginator)
     """
 
     def paginate(
-        self, *, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListGamesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListGames.paginate)
@@ -113,14 +112,14 @@ class ListGamesPaginator(Boto3Paginator):
         """
 
 
-class ListGeneratedCodeJobsPaginator(Boto3Paginator):
+class ListGeneratedCodeJobsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListGeneratedCodeJobs)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_gamesparks/paginators/#listgeneratedcodejobspaginator)
     """
 
     def paginate(
-        self, *, GameName: str, SnapshotId: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, GameName: str, SnapshotId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListGeneratedCodeJobsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListGeneratedCodeJobs.paginate)
@@ -128,14 +127,14 @@ class ListGeneratedCodeJobsPaginator(Boto3Paginator):
         """
 
 
-class ListSnapshotsPaginator(Boto3Paginator):
+class ListSnapshotsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListSnapshots)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_gamesparks/paginators/#listsnapshotspaginator)
     """
 
     def paginate(
-        self, *, GameName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, GameName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListSnapshotsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListSnapshots.paginate)
@@ -143,14 +142,14 @@ class ListSnapshotsPaginator(Boto3Paginator):
         """
 
 
-class ListStageDeploymentsPaginator(Boto3Paginator):
+class ListStageDeploymentsPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListStageDeployments)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_gamesparks/paginators/#liststagedeploymentspaginator)
     """
 
     def paginate(
-        self, *, GameName: str, StageName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, GameName: str, StageName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListStageDeploymentsResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListStageDeployments.paginate)
@@ -158,14 +157,14 @@ class ListStageDeploymentsPaginator(Boto3Paginator):
         """
 
 
-class ListStagesPaginator(Boto3Paginator):
+class ListStagesPaginator(Paginator):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListStages)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_gamesparks/paginators/#liststagespaginator)
     """
 
     def paginate(
-        self, *, GameName: str, PaginationConfig: "PaginatorConfigTypeDef" = ...
+        self, *, GameName: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListStagesResultTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/gamesparks.html#GameSparks.Paginator.ListStages.paginate)
